==> seedsui-react-2.6.2.tgz: package/es/Toast/Toast.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { createPortal } from 'react-dom';

var Toast = (_temp = _class = function (_Component) {
  _inherits(Toast, _Component);

  function Toast(props) {
    _classCallCheck(this, Toast);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.componentDidMount = function () {};

    return _this;
  }

  Toast.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        portal = _props.portal,
        show = _props.show,
        duration = _props.duration,
        maskClassName = _props.maskClassName,
        maskStyle = _props.maskStyle,
        className = _props.className,
        style = _props.style,
        icon = _props.icon,
        caption = _props.caption,
        captionStyle = _props.captionStyle,
        captionClassName = _props.captionClassName,
        others = _objectWithoutProperties(_props, ['portal', 'show', 'duration', 'maskClassName', 'maskStyle', 'className', 'style', 'icon', 'caption', 'captionStyle', 'captionClassName']);

    return createPortal(React.createElement(
      'div',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        }, className: 'mask toast-mask' + (maskClassName ? ' ' + maskClassName : '') + (show ? ' active' : ''), style: Object.assign(duration !== undefined ? { WebkitTransitionDuration: duration + 'ms' } : {}, maskStyle) }, others),
      React.createElement(
        'div',
        { className: 'toast' + (className ? ' ' + className : '') + (show ? ' active' : ''), style: Object.assign(duration !== undefined ? { WebkitTransitionDuration: duration + 'ms' } : {}, style) },
        React.createElement(
          'div',
          { className: 'toast-wrapper' },
          icon,
          caption && React.createElement(
            'span',
            { className: 'toast-caption' + (captionClassName ? ' ' + captionClassName : ''), style: captionStyle },
            caption
          )
        )
      )
    ), this.props.portal || document.getElementById('root'));
  };

  return Toast;
}(Component), _class.defaultProps = {}, _temp);
export { Toast as default };
Toast.propTypes = process.env.NODE_ENV !== "production" ? {
  portal: PropTypes.object,

  show: PropTypes.bool,

  duration: PropTypes.number,

  maskClassName: PropTypes.string,
  maskStyle: PropTypes.object,

  className: PropTypes.string,
  style: PropTypes.object,

  caption: PropTypes.node,
  captionStyle: PropTypes.object,
  captionClassName: PropTypes.string,

  icon: PropTypes.node
} : {};

==> seedsui-react-2.6.8.tgz: package/es/Toast/Toast.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { createPortal } from 'react-dom';

var Toast = (_temp = _class = function (_Component) {
  _inherits(Toast, _Component);

  function Toast(props) {
    _classCallCheck(this, Toast);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.componentDidMount = function () {};

    return _this;
  }

  Toast.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        portal = _props.portal,
        show = _props.show,
        _props$maskAttribute = _props.maskAttribute,
        maskAttribute = _props$maskAttribute === undefined ? {} : _props$maskAttribute,
        icon = _props.icon,
        caption = _props.caption,
        _props$captionAttribu = _props.captionAttribute,
        captionAttribute = _props$captionAttribu === undefined ? {} : _props$captionAttribu,
        others = _objectWithoutProperties(_props, ['portal', 'show', 'maskAttribute', 'icon', 'caption', 'captionAttribute']);

    return createPortal(React.createElement(
      'div',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        } }, maskAttribute, { className: 'mask toast-mask' + (maskAttribute.className ? ' ' + maskAttribute.className : '') + (show ? ' active' : '') }),
      React.createElement(
        'div',
        _extends({}, others, { className: 'toast' + (others.className ? ' ' + others.className : '') + (show ? ' active' : '') }),
        React.createElement(
          'div',
          { className: 'toast-wrapper' },
          icon,
          caption && React.createElement(
            'span',
            _extends({}, captionAttribute, { className: 'toast-caption' + (captionAttribute.className ? ' ' + captionAttribute.className : '') }),
            caption
          )
        )
      )
    ), this.props.portal || document.getElementById('root'));
  };

  return Toast;
}(Component), _class.defaultProps = {}, _temp);
export { Toast as default };
Toast.propTypes = process.env.NODE_ENV !== "production" ? {
  portal: PropTypes.object,

  show: PropTypes.bool,

  maskAttribute: PropTypes.object,

  caption: PropTypes.node,
  captionAttribute: PropTypes.object,

  icon: PropTypes.node
} : {};
